==> alfresco-remote-api-16.36-sources.jar: org/alfresco/rest/api/search/model/SortDef.java <==
/*-
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.rest.api.search.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * This is a copy of the SortDefinition class found in data-model.  Due to the use of a very old version
 * of Jackson it is necessary to duplicate this class rather than reuse it.
 *
 * @author Gethin James
 */
public class SortDef
{

    String type;
    String field;
    boolean ascending;

    @JsonCreator
    public SortDef(@JsonProperty("type") String type,
                   @JsonProperty("field")  String field,
                   @JsonProperty("ascending") boolean ascending)
    {
        this.type = type;
        this.field = field;
        this.ascending = ascending;
    }

    public String getType()
    {
        return type;
    }

    public String getField()
    {
        return field;
    }

    public boolean isAscending()
    {
        return ascending;
    }
}

==> alfresco-remote-api-26.1.0.41-sources.jar: org/alfresco/rest/api/search/model/SortDef.java <==
/*-
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.rest.api.search.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * This is a copy of the SortDefinition class found in data-model. Due to the use of a very old version of Jackson it is necessary to duplicate this class rather than reuse it.
 *
 * @author Gethin James
 */
public class SortDef
{

    String type;
    String field;
    boolean ascending;

    @JsonCreator
    public SortDef(@JsonProperty("type") String type,
            @JsonProperty("field") String field,
            @JsonProperty("ascending") boolean ascending)
    {
        this.type = type;
        this.field = field;
        this.ascending = ascending;
    }

    public String getType()
    {
        return type;
    }

    public String getField()
    {
        return field;
    }

    public boolean isAscending()
    {
        return ascending;
    }
}
